<template>
  <div class="chart-itm-equ-line">
    <div class="tooltips flex">
      <div class="flex1 flex tooltip">
        <div class="chart-status-dot green"></div>
        <div class="chart-status-desc">正常设备</div>
      </div>
      <div class="flex1 flex tooltip">
        <div class="chart-status-dot yellow"></div>
        <div class="chart-status-desc">>警告设备</div>
      </div>
      <div class="flex1 flex tooltip">
        <div class="chart-status-dot red"></div>
        <div class="chart-status-desc">异常设备</div>
      </div>
    </div>
    <div class="chart-itm-equ-line-echarts" :id="eid"></div>

  </div>
</template>

<script>
import "echarts-liquidfill";

import * as echarts from "echarts";
export default {
  props: {
    areas: []
  },
  data() {
    return {
      eid: "chart-itm-equ-line",
      option: {},
      total: 0,
    };
  },
  methods: {
    initChart() {
      var value = 0.56;
      var v1 = 0, v2 = 0, v3 = 0;
      var codes = []
      var arr_v1 = []
      var arr_v2 = []
      var arr_v3 = []
      for (var item of this.areas) {
        v1 += parseInt(item.areaStatic.normal || 0)
        v2 += parseInt(item.areaStatic.warn || 0)
        v3 += parseInt(item.areaStatic.alarm || 0)
        codes.push(item.areaCode + '区')
        arr_v1.push(parseInt(item.areaStatic.normal || 0) || 0)
        arr_v2.push(parseInt(item.areaStatic.warn || 0) || 0)
        arr_v3.push(parseInt(item.areaStatic.alarm || 0) || 0)
      }
      this.total = v1 + v2 + v3
      // console.log('v1', v1, v2, v3)


      this.option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // Use axis to trigger tooltip
            type: 'shadow' // 'shadow' as default; can also be 'line' or 'shadow'
          }
        },
        grid: {
          top: '1%',
          left: '0%',
          right: '3%',
          bottom: '2%',
          containLabel: true
        },
        xAxis: {
          type: 'value'
        },
        yAxis: {
          type: 'category',
          data: codes
        },
        series: [
          {
            name: '正常',
            type: 'bar',
            stack: 'total',
            label: {
              show: true
            },
            itemStyle: {
              normal: {
                color: new echarts.graphic.LinearGradient(0.2, 1, 0.3, 0, [
                  {
                    offset: 1,
                    color: "rgba(6, 188, 117, 1)",
                  },
                  {
                    offset: 0,
                    color: "rgba(6, 188, 117, 1)",
                  },
                ]),
              },
            },
            emphasis: {
              focus: 'series'
            },
            data: arr_v1
          },
          {
            name: '警告',
            type: 'bar',
            stack: 'total',
            label: {
              // show: true
            },
            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              normal: {
                color: new echarts.graphic.LinearGradient(0.2, 1, 0.3, 0, [
                  {
                    offset: 1,
                    color: "rgba(221, 175, 1, 1)",
                  },
                  {
                    offset: 0,
                    color: "rgba(221, 175, 1, 1)",
                  },
                ]),
              },
            },
            data: arr_v2
          },
          {
            name: '异常',
            type: 'bar',
            stack: 'total',
            label: {
              // show: true
            },
            itemStyle: {
              normal: {
                color: new echarts.graphic.LinearGradient(0.2, 1, 0.3, 0, [
                  {
                    offset: 1,
                    color: "rgba(241, 76, 3, 1)",
                  },
                  {
                    offset: 0,
                    color: "rgba(241, 76, 3, 1)",
                  },
                ]),
              },
            },
            emphasis: {
              focus: 'series'
            },
            data: arr_v3
          }
        ]
      };

      this.option && this.myChart.setOption(this.option);
    },
  },
  mounted() {
    this.chartDom = document.getElementById(this.eid);
    this.myChart = echarts.init(this.chartDom);
    this.initChart();
  },
};
</script>

<style lang="scss" scope>
.chart-itm-equ-line {
  height: 44rem;
  width: 40rem;

  position: relative;

  .tooltips {
    width: 21rem;
    height: 2.25rem;
    background: #e3edf8;
    border-radius: 1.42rem;
    position: absolute;
    bottom: -3rem;
    left: calc((100% - 21rem) / 2);

    .tooltip {
      margin: 0 auto;
      margin-top: 0.4rem;
      max-width: fit-content;

      .chart-status-dot {
        width: 0.5rem;
        height: 0.5rem;
        border-radius: 50%;
        margin-top: 0.5rem;
        margin-right: 0.5rem;
      }

      .chart-status-dot.green {
        background: rgba(13, 190, 121, 1);
      }

      .chart-status-dot.red {
        background: rgba(242, 82, 2, 1);
      }

      .chart-status-dot.yellow {
        background: rgba(223, 177, 2, 1);
      }

      .chart-status-desc {
        font-size: 1rem;
        font-family: PingFangSC-Regular, PingFang SC;
        font-weight: 400;
        color: #6c99be;
        line-height: 1.42rem;
      }
    }
  }

  .chart-itm-equ-line-echarts {
    height: 44rem;
    width: 40rem;
  }

  .sub-div {
    background: linear-gradient(180deg,
        #d2e0f1 0%,
        rgba(219, 233, 243, 0) 100%);
    border-radius: 50%;
    height: 14rem;
    width: 14rem;
    left: 8.5rem;
    position: absolute;
    top: 3rem;
  }

  .sub-insidemask-div {
    position: absolute;
    left: 11.3rem;
    top: 2.8rem;
    top: 5.8rem;
    width: 8.4rem;
    height: 8.4rem;

    border-radius: 150px;
    /* background-color: white; */
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    font-size: 25px;
    font-weight: bold;
    /* background: linear-gradient(180deg, #e6eff8 0%, #dde8f4 100%); */
    box-shadow: 0rem 0.33rem 1.17rem 0rem rgba(47, 108, 156, 0.29);

    .temperature-num {
      font-size: 2.5rem;
      font-family: Impact;
      color: #278afa;
      line-height: 3rem;
    }

    .temperature-unit {
      font-size: 1.17rem;
      font-family: PingFangSC-Semibold, PingFang SC;
      font-weight: 600;
      color: #333333;
    }
  }
}
</style>